// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIDLETIME_VERSION_H
#define KIDLETIME_VERSION_H

#define KIDLETIME_VERSION_STRING "6.26.0"
#define KIDLETIME_VERSION_MAJOR 6
#define KIDLETIME_VERSION_MINOR 26
#define KIDLETIME_VERSION_PATCH 0
#define KIDLETIME_VERSION ((6<<16)|(26<<8)|(0))

#endif
